import { TypedEventEmitter } from '@libp2p/interface';
import { type Multiaddr } from '@multiformats/multiaddr';
import type { Components } from './components.js';
import type { Libp2p, Libp2pInit, Libp2pOptions } from './index.js';
import type { PeerRouting, ContentRouting, Libp2pEvents, PendingDial, ServiceMap, AbortOptions, ComponentLogger, Connection, NewStreamOptions, Stream, Metrics, PeerId, PeerStore, Topology, Libp2pStatus, IsDialableOptions } from '@libp2p/interface';
import type { StreamHandler, StreamHandlerOptions } from '@libp2p/interface-internal';
export declare class Libp2pNode<T extends ServiceMap = ServiceMap> extends TypedEventEmitter<Libp2pEvents> implements Libp2p<T> {
    #private;
    peerId: PeerId;
    peerStore: PeerStore;
    contentRouting: ContentRouting;
    peerRouting: PeerRouting;
    metrics?: Metrics;
    services: T;
    logger: ComponentLogger;
    status: Libp2pStatus;
    components: Components & T;
    private readonly log;
    constructor(init: Libp2pInit<T> & Required<Pick<Libp2pInit<T>, 'peerId'>>);
    private configureComponent;
    /**
     * Starts the libp2p node and all its subsystems
     */
    start(): Promise<void>;
    /**
     * Stop the libp2p node by closing its listeners and open connections
     */
    stop(): Promise<void>;
    getConnections(peerId?: PeerId): Connection[];
    getDialQueue(): PendingDial[];
    getPeers(): PeerId[];
    dial(peer: PeerId | Multiaddr | Multiaddr[], options?: AbortOptions): Promise<Connection>;
    dialProtocol(peer: PeerId | Multiaddr | Multiaddr[], protocols: string | string[], options?: NewStreamOptions): Promise<Stream>;
    getMultiaddrs(): Multiaddr[];
    getProtocols(): string[];
    hangUp(peer: PeerId | Multiaddr, options?: AbortOptions): Promise<void>;
    /**
     * Get the public key for the given peer id
     */
    getPublicKey(peer: PeerId, options?: AbortOptions): Promise<Uint8Array>;
    handle(protocols: string | string[], handler: StreamHandler, options?: StreamHandlerOptions): Promise<void>;
    unhandle(protocols: string[] | string): Promise<void>;
    register(protocol: string, topology: Topology): Promise<string>;
    unregister(id: string): void;
    isDialable(multiaddr: Multiaddr, options?: IsDialableOptions): Promise<boolean>;
}
/**
 * Returns a new Libp2pNode instance - this exposes more of the internals than the
 * libp2p interface and is useful for testing and debugging.
 */
export declare function createLibp2pNode<T extends ServiceMap = ServiceMap>(options?: Libp2pOptions<T>): Promise<Libp2pNode<T>>;
//# sourceMappingURL=libp2p.d.ts.map